@@ -43,8 +43,8 @@
 
 /* NDB version numbers and status  */
 #define NDB_VERSION_MAJOR 7
-#define NDB_VERSION_MINOR 5
-#define NDB_VERSION_BUILD 25
+#define NDB_VERSION_MINOR 6
+#define NDB_VERSION_BUILD 21
 #define NDB_VERSION_STATUS ""
 
 /* Composite version number for NDB */
@@ -107,6 +107,7 @@ Uint32 ndbGetOwnVersion();
  */
 #define NDB_BACKUP_VERSION NDB_MAKE_VERSION(6,3,11)
 
+#define NDB_DISK_V2 NDB_MAKE_VERSION(7,6,0)
 /**
  * From which version do we support rowid
  */ 
@@ -138,6 +139,7 @@ Uint32 ndbGetOwnVersion();
 #define NDBD_MT_LQH_VERSION MAKE_VERSION(6,4,0)
 
 #define NDBD_SCHEMA_TRANS_VERSION NDB_MAKE_VERSION(6,4,0)
+#define NDBD_LOCAL_SYSFILE_VERSION NDB_MAKE_VERSION(7,6,3)
 
 static
 inline
@@ -798,6 +800,24 @@ ndbd_fixed_lookup_query_abort(Uint32 x)
   return x >= NDBD_FIXED_LOOKUP_QUERY_ABORT_72;
 }
 
+/**
+ * Including vers. 'NDBD_SPJ_API_ONLY_LONG_TRANSID_AI',
+ * TRANSID_AI received from a SPJ query execution
+ * was required to always be a 'long signal'.
+ * (As it was always sent with the FLUSH_AI pseudo-read)
+ * From Cluster 7.6.2 and up, TRANSID_AI results rows from
+ * SPJ execution can be sent as (packed) 'short' signals.
+ */
+#define NDBD_SPJ_API_ONLY_LONG_TRANSID_AI NDB_MAKE_VERSION(7,6,1)
+
+static
+inline
+int
+ndbd_spj_api_support_short_TRANSID_AI(Uint32 x)
+{
+  return x > NDBD_SPJ_API_ONLY_LONG_TRANSID_AI;
+}
+
 /**
  * NOTE1:
  *   Even though pushed join support wasn't GA intil 7.2.4
@@ -811,11 +831,33 @@ ndbd_fixed_lookup_query_abort(Uint32 x)
 static
 inline
 int
-ndb_join_pushdown(Uint32 x)
+ndbd_join_pushdown(Uint32 x)
 {
   return x >= NDBD_JOIN_PUSHDOWN;
 }
 
+/**
+ * An enhanced version of the SCAN_FRAGREQ signal has been
+ * introduced in 7.6.4, where multiple fragments to be scanned
+ * can be specified in a single 'REQ'.
+ *
+ * At the same time an updated version of QueryNode introduced
+ * a new QN_SCAN_FRAG OpNode type, with an extended format
+ * for specifying the scan 'batchSize'.
+ *
+ * That also deprecated (still supported) the former 'SCAN' type
+ * QueryNode into QN_SCAN_FRAG_v1 and QN_SCAN_INDEX_v1.
+ */
+#define NDBD_SPJ_MULTIFRAG_SCAN NDB_MAKE_VERSION(7,6,4)
+
+static
+inline
+int
+ndbd_spj_multifrag_scan(Uint32 x)
+{
+  return x >= NDBD_SPJ_MULTIFRAG_SCAN;
+}
+
 /**
  * DICT did not have a function for receiving GET_TABINFOREF signals
  * (see Bug#14647210).
@@ -905,13 +947,16 @@ ndbd_multi_tc_instance_takeover(Uint32 x)
 /**
  * Support for wl#9819 ndbinfo.processes
  */
-#define NDBD_PROCESSINFO_VERSION NDB_MAKE_VERSION(7,5,7)
+#define NDBD_PROCESSINFO_VERSION_75 NDB_MAKE_VERSION(7,5,7)
+#define NDBD_PROCESSINFO_VERSION_76 NDB_MAKE_VERSION(7,6,2)
+#define RELEASE_7_6_0 NDB_MAKE_VERSION(7,6,0)
 static
 inline
 int
 ndbd_supports_processinfo(Uint32 x)
 {
-  if(x < NDBD_PROCESSINFO_VERSION)
+  if(x < NDBD_PROCESSINFO_VERSION_75 ||
+    (x >= RELEASE_7_6_0 && x < NDBD_PROCESSINFO_VERSION_76))
   {
     return 0;
   }
@@ -1096,6 +1141,59 @@ ndbd_support_fully_replicated(Uint32 x)
   return 1;
 }
 
+/**
+ * Uses new Partial LCP format for LCPs
+ */
+#define NDBD_USE_PARTIAL_LCP_v1 NDB_MAKE_VERSION(7,6,3)
+#define NDBD_USE_PARTIAL_LCP_v2 NDB_MAKE_VERSION(7,6,4)
+
+static
+inline
+int
+ndbd_use_partial_lcp(Uint32 x)
+{
+  const Uint32 major = (x >> 16) & 0xFF;
+  const Uint32 minor = (x >>  8) & 0xFF;
+  if (major < 7)
+  {
+    return 0;
+  }
+  else if (major == 7)
+  {
+    if (minor < 5)
+    {
+      return 0;
+    }
+    else if (minor == 5)
+    {
+      return x >= NDBD_USE_PARTIAL_LCP_v2;
+    }
+  }
+  return 1;
+}
+
+/**
+ * Enable Redo control for LCPs
+ */
+#define NDBD_ENABLE_REDO_CONTROL_76 NDB_MAKE_VERSION(7,6,8)
+#define NDBD_ENABLE_REDO_CONTROL_80 NDB_MAKE_VERSION(8,0,14)
+static
+inline
+int
+ndbd_enable_redo_control(Uint32 x)
+{
+  const Uint32 major = (x >> 16) & 0xFF;
+  if (major < 7)
+  {
+    return 0;
+  }
+  else if (major == 7)
+  {
+    return x >= NDBD_ENABLE_REDO_CONTROL_76;
+  }
+  return x >= NDBD_ENABLE_REDO_CONTROL_80;
+}
+
 
 #define NDBD_WAITGCP_SHUTDOWNSYNC_73 NDB_MAKE_VERSION(7,3,30)
 #define NDBD_WAITGCP_SHUTDOWNSYNC_74 NDB_MAKE_VERSION(7,4,29)
